<?php

// Max Content Width
if ( ! isset( $content_width ) ) { $content_width = 752; }

function richwp_content_width() {
	if ( is_page_template( 'page-fullwidth.php' )  || is_page_template( 'page-fullwidth-no-title.php' )   ) {
		global $content_width;
		$content_width = 1264;
	}
}
add_action( 'template_redirect', 'richwp_content_width' );

// Back Combat
if ( version_compare( $GLOBALS['wp_version'], '4.1-alpha', '<' ) ) {
	require get_template_directory() . '/inc/back-compat.php';
}

function my_myme_types($mime_types){
	//Adding svg extension
    $mime_types['svg'] = 'image/svg+xml'; 
    return $mime_types;
}
add_filter('upload_mimes', 'my_myme_types', 1, 1);


// Setup 
if ( ! function_exists( 'richwp_setup' ) ) :

function richwp_setup() {

	// Tranlation Ready
	load_theme_textdomain( 'video-world', get_template_directory() . '/languages' );

	// RSS feed links
	add_theme_support( 'automatic-feed-links' );

	// Document title 
	add_theme_support( 'title-tag' );

	//Post Thumbnails & Image Sizes
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 620, 383, true );

	// Menus
	register_nav_menus( array(
		'primary' => __( 'Primary Menu',      'video-world' ),
		'iconmenu' => __( 'Icon Menu', 'video-world' ),
		'selectmenu1' => __( 'Select Menu 1', 'video-world' ),
		'selectmenu2' => __( 'Select Menu 2', 'video-world' ),
		'footer' => __( 'Footer Navigation', 'video-world' ),
	) );

	// HTML5 Forms
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	) );

	// Post Formats
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link', 'gallery', 'status', 'audio', 'chat'
	) );


	// Woo Commerce Support
	if ( function_exists( 'is_woocommerce' ) ) {

		add_theme_support( 'woocommerce' );
	    remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10);  
	    remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
		remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10); 
		remove_action( 'woocommerce_after_shop_loop', 'woocommerce_pagination', 10 );
		add_action( 'woocommerce_after_shop_loop', 'my_pagination', 10 );	
		function my_pagination() {
				the_posts_pagination( array(
					'prev_text'          => __( 'Previous Products', 'video-world' ),
					'next_text'          => __( 'Next Products', 'video-world' ),
					'before_page_number' => '<span class="meta-nav screen-reader-text">' . __( 'Product Page', 'video-world' ) . ' </span>',
				) );
			}
		remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );
		remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20 );
		remove_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30 );
		
		// Shop Select Menus
		add_action( 'woocommerce_before_shop_loop', 'rich_shopselect', 10 );
	
		function rich_shopselect() {
		
		if ( has_nav_menu( 'selectmenushop' ) ) {
			echo'<div class="selectwrap">';
			wp_nav_menu( array( 'container' => false, 'fallback_cb' => false, 'menu_id' => 'selectmenushop', 'menu_class' => 'richselectmenushop', 'theme_location' => 'selectmenushop', 'depth' => -1 ) );
		echo '</div>';
		
		}  

		}
		
		register_nav_menus( array(
			
			'selectmenushop' => __( 'Select Menu Shop', 'video-world' ),
		
		) );
		

		
		function my_dequeue_script() {
			wp_dequeue_script('chosen');
			wp_dequeue_script('select2');

		}
		
		add_action( 'wp_print_scripts', 'my_dequeue_script', 100 );	

		/**
		 * Optimize WooCommerce Scripts
		 * Remove WooCommerce Generator tag, styles, and scripts from non WooCommerce pages.
		 */
		add_action( 'wp_enqueue_scripts', 'child_manage_woocommerce_styles', 99 );
		
		function child_manage_woocommerce_styles() {
			//remove generator meta tag
			remove_action( 'wp_head', array( $GLOBALS['woocommerce'], 'generator' ) );
			
		
			//first check that woo exists to prevent fatal errors
			if ( function_exists( 'is_woocommerce' ) ) {
				if ( is_woocommerce() || is_cart() ||  is_checkout() ) {

						wp_enqueue_style( 'richwp-woo', get_template_directory_uri() . '/css/woostyles.css' );
					
				}
				//dequeue scripts and styles
				if ( ! is_woocommerce() && ! is_cart() && ! is_checkout() ) {
					wp_dequeue_style( 'woocommerce-general' );
					wp_dequeue_style( 'woocommerce-layout' );
					wp_dequeue_style( 'woocommerce-smallscreen' );
					wp_dequeue_style( 'woocommerce_frontend_styles' );
					wp_dequeue_style( 'woocommerce_fancybox_styles' );
					wp_dequeue_style( 'woocommerce_chosen_styles' );
					wp_dequeue_style( 'woocommerce_prettyPhoto_css' );
					wp_dequeue_script( 'wc_price_slider' );
					wp_dequeue_script( 'wc-single-product' );
					wp_dequeue_script( 'wc-add-to-cart' );
					wp_dequeue_script( 'wc-cart-fragments' );
					wp_dequeue_script( 'wc-checkout' );
					wp_dequeue_script( 'wc-add-to-cart-variation' );
					wp_dequeue_script( 'wc-single-product' );
					wp_dequeue_script( 'wc-cart' );
					wp_dequeue_script( 'wc-chosen' );
					wp_dequeue_script( 'woocommerce' );
					wp_dequeue_script( 'prettyPhoto' );
					wp_dequeue_script( 'prettyPhoto-init' );
					wp_dequeue_script( 'jquery-blockui' );
					wp_dequeue_script( 'jquery-placeholder' );
					wp_dequeue_script( 'fancybox' );
					wp_dequeue_script( 'jqueryui' );
				}
			}
		
		}
	}
} // first check if Woo Commerce is activated

endif; // richwp_setup
add_action( 'after_setup_theme', 'richwp_setup' );

// Register Widget Areas
function richwp_widgets_init() {
	
	// Primary Sidebar
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'video-world' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Add widgets here to appear in your sidebar.', 'video-world' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	
	// Header Widget Area
	register_sidebar( array(
		'name'          => __( 'Header Widget Area', 'video-world' ),
		'id'            => 'header-widget-area',
		'description'   => __( 'Add widgets here to appear in the Header.', 'video-world' ),
		'before_widget' => '<aside id="%1$s" class="widget header-widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	
	// Featured Posts Widget Area
	register_sidebar( array(
		'name'          => __( 'Featured Posts Widget Area', 'video-world' ),
		'id'            => 'featured-widget-area',
		'description'   => __( 'Add widgets here to appear next to your featured posts area.', 'video-world' ),
		'before_widget' => '<aside id="%1$s" class="widget featured-widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	
	// Top Widget Area
	register_sidebar( array(
		'name'          => __( 'Top Widget Area', 'video-world' ),
		'id'            => 'top-widget-area',
		'description'   => __( 'Add widgets here to appear on top of your content area.', 'video-world' ),
		'before_widget' => '<aside id="%1$s" class="widget top-widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	
	// Top Postlist Widget Area
	register_sidebar( array(
		'name'          => __( 'Top Postlist Widget Area', 'video-world' ),
		'id'            => 'toppostlist-widget-area',
		'description'   => __( 'Add widgets here to appear above your postlists / archives.', 'video-world' ),
		'before_widget' => '<aside id="%1$s" class="widget toppostlist-widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	
	// Below Content Widget Area
	register_sidebar( array(
		'name'          => __( 'Below Content Widget Area', 'video-world' ),
		'id'            => 'below-content-widget-area',
		'description'   => __( 'Add widgets here to appear below your content area.', 'video-world' ),
		'before_widget' => '<aside id="%1$s" class="widget below-content-widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	
	// Below Comments Widget Area
	register_sidebar( array(
		'name'          => __( 'Below Comments Widget Area', 'video-world' ),
		'id'            => 'below-comments-widget-area',
		'description'   => __( 'Add widgets here to appear below your comment area.', 'video-world' ),
		'before_widget' => '<aside id="%1$s" class="widget below-comments-widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	
	// First Footer Widget Area
	register_sidebar( array (
		'name' => __( 'First Footer Widget Area', 'video-world' ),
		'id' => 'first-footer-widget-area',
		'description' => __( 'Add widgets here to appear in the first footer widget area.' , 'video-world' ),
		'before_widget' => '<aside id="%1$s" class="widget footer-widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h2 class="widget-title widget-title-bottom">',
		'after_title' => '</h2>',
	) );

	// Second Footer Widget Area
	register_sidebar( array (
		'name' => __( 'Second Footer Widget Area', 'video-world' ),
		'id' => 'second-footer-widget-area',
		'description' => __( 'Add widgets here to appear in the second footer widget area.' , 'video-world' ),
		'before_widget' => '<aside id="%1$s" class="widget footer-widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h2 class="widget-title widget-title-bottom">',
		'after_title' => '</h2>',
	) );

	// Third Footer Widget Area
	register_sidebar( array (
		'name' => __( 'Third Footer Widget Area', 'video-world' ),
		'id' => 'third-footer-widget-area',
		'description' => __( 'Add widgets here to appear in the third footer widget area.' , 'video-world' ),
		'before_widget' => '<aside id="%1$s" class="widget footer-widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h2 class="widget-title widget-title-bottom">',
		'after_title' => '</h2>',
	) );

	// Fourth Footer Widget Area
	register_sidebar( array (
		'name' => __( 'Fourth Footer Widget Area', 'video-world'),
		'id' => 'fourth-footer-widget-area',
		'description' => __( 'Add widgets here to appear in the fourth footer widget area.' , 'video-world' ),
		'before_widget' => '<aside id="%1$s" class="widget footer-widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h2 class="widget-title widget-title-bottom">',
		'after_title' => '</h2>',
	) );
	
	// Top Widget Area
	register_sidebar( array(
		'name'          => __( 'Bottom Widget Area', 'video-world' ),
		'id'            => 'bottom-widget-area',
		'description'   => __( 'Add widgets here to appear at the bottom of your site.', 'video-world' ),
		'before_widget' => '<aside id="%1$s" class="widget bottom-widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'richwp_widgets_init' );


if ( ! function_exists( 'richwp_fonts_url' ) ) :
// Google Fonts

function richwp_fonts_url() {
	$fonts_url = '';
	$fonts     = array();
	$subsets   = 'latin,latin-ext';

	/* translators: If there are characters in your language that are not supported by Ek Mukta, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Ek Mukta font: on or off', 'video-world' ) ) {
		$fonts[] = 'Ek Mukta:200,800';
	}

	/* translators: To add an additional character subset specific to your language, translate this to 'greek', 'cyrillic', 'devanagari' or 'vietnamese'. Do not translate into your own language. */
	$subset = _x( 'no-subset', 'Add new subset (greek, cyrillic, devanagari, vietnamese)', 'video-world' );

	if ( 'cyrillic' == $subset ) {
		$subsets .= ',cyrillic,cyrillic-ext';
	} elseif ( 'greek' == $subset ) {
		$subsets .= ',greek,greek-ext';
	} elseif ( 'devanagari' == $subset ) {
		$subsets .= ',devanagari';
	} elseif ( 'vietnamese' == $subset ) {
		$subsets .= ',vietnamese';
	}

	if ( $fonts ) {
		$fonts_url = add_query_arg( array(
			'family' => urlencode( implode( '|', $fonts ) ),
			'subset' => urlencode( $subsets ),
		), '//fonts.googleapis.com/css' );
	}

	return $fonts_url;
}
endif;

// Scripts and styles
function richwp_scripts() {
	// Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'richwp-fonts', richwp_fonts_url(), array(), null );

	// Load our main stylesheet.
	wp_enqueue_style( 'richwp-style', get_stylesheet_uri() );
	
	
	// Load the Internet Explorer 9 specific stylesheet.
	wp_enqueue_style( 'richwp-ie9', get_template_directory_uri() . '/css/ie9.css', array( 'richwp-style' ), '20151113' );
	wp_style_add_data( 'richwp-ie9', 'conditional', 'IE 9' );

	// Load the Internet Explorer specific stylesheet.
	wp_enqueue_style( 'richwp-ie', get_template_directory_uri() . '/css/ie.css', array( 'richwp-style' ), '20151113' );
	wp_style_add_data( 'richwp-ie', 'conditional', 'lt IE 10' );
	

	// Add jQuery
	
	wp_enqueue_script( 'modernizr', get_template_directory_uri() . '/js/modernizr.js', array('jquery'), '1.0', false);
    wp_enqueue_script( 'msn-main', get_template_directory_uri() . '/js/main.js', array('jquery'), '1.0', true);

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}


	wp_enqueue_script( 'richwp-script', get_template_directory_uri() . '/js/functions.js', array( 'jquery' ), '20141212', true );
	wp_localize_script( 'richwp-script', 'screenReaderText', array(
		'expand'   => '<span class="screen-reader-text">' . __( 'expand child menu', 'video-world' ) . '</span>',
		'collapse' => '<span class="screen-reader-text">' . __( 'collapse child menu', 'video-world' ) . '</span>',
	) );
	

}
add_action( 'wp_enqueue_scripts', 'richwp_scripts' );

// Editor Styles
function richwp_editor_styles() {
    add_editor_style( 'css/editor-style.css' );
}
add_action( 'admin_init', 'richwp_editor_styles' );

// Excerpt Lenght
function custom_excerpt_length( $length ) {
	return 35;
}
add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );

/* Featured Posts from Menu List */
include "inc/functions-menu-list.php";

// Custom template tags for this theme.
require get_template_directory() . '/inc/template-tags.php';

// Customizer additions.
 
require get_template_directory() . '/inc/richwp-options.php';